NullValue

Enum NullValue 

pub enum NullValue {
    Ignore,
    Null,
    EmptyObject,
    EmptyString,
}
Defines how empty elements like <x /> should be handled. Ignore -> exclude from JSON, Null -> "x":null, EmptyObject -> "x":{}, EmptyString -> "x":"". EmptyObject is the default option and is how it was handled prior to v.0.4 Using Ignore on an XML document with an empty root element falls back to Null option. E.g. both <a><x/></a> and <a/> are converted into {"a":null}.

Variants



Ignore



Null



EmptyObject



EmptyString